using System;
using System.IO;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Net;
using WindowsLive.Writer.Api;


namespace InsertFileViaFtp
{
    public partial class UploadForm : Form
    {
        public string linkUrl = string.Empty;
        public string displayText = string.Empty;

        public UploadForm()
        {
            InitializeComponent();

            // load in the FTP servers from the App.config file
            LoadFTPSites();
        }

        private void LoadFTPSites()
        {
            string xmlFilename = AppDomain.CurrentDomain.BaseDirectory + @"Plugins\InsertFileViaFtp.dll.xml";
            XmlDocument xmlDoc = new XmlDocument();
            xmlDoc.Load(xmlFilename);
            foreach (XmlNode node in xmlDoc.SelectNodes(@"/ftpservers/*"))
            {
                FTPSite obj = new FTPSite(node);
                cboFTPServer.Items.Add(obj);
                if (obj.IsDefault)
                    cboFTPServer.SelectedItem = obj;
            }
        }

        private void btnBrowseForFile_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                txtFilename.Text = openFileDialog1.FileName;
                SetDisplayText();
            }
        }

        private void SetDisplayText()
        {
            if (txtFilename.Text.Length > 0)
            {
                FTPSite ftpSite = (FTPSite)cboFTPServer.SelectedItem;
                txtDisplayText.Text = ftpSite.LinkUrl + (new FileInfo(txtFilename.Text)).Name;
            }
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            if (txtFilename.Text != string.Empty)
            {
                // ftp upload the file
                string fileName = txtFilename.Text;
                FTPSite ftpSite = (FTPSite)cboFTPServer.SelectedItem;
                string fileUrl = ftpSite.ServerUri + HtmlServices.HtmlEncode(new FileInfo(fileName).Name);
                if (ftpSite.Debug)
                    MessageBox.Show("Uploading file to " + fileUrl);
                using (WebClient client = new WebClient())
                {
                    client.Credentials = new System.Net.NetworkCredential(ftpSite.Username, ftpSite.Password);
                    client.UploadFile(fileUrl, "STOR", fileName);
                    linkUrl = ftpSite.LinkUrl + new FileInfo(fileName).Name;
                    displayText = txtDisplayText.Text;
                }
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {

        }

        private void cboFTPServer_SelectedIndexChanged(object sender, EventArgs e)
        {
            SetDisplayText();
        }

    }
}